hyperspy\.external\.astroML package
===================================

Submodules
----------

hyperspy\.external\.astroML\.bayesian\_blocks module
----------------------------------------------------

.. automodule:: hyperspy.external.astroML.bayesian_blocks
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.external\.astroML\.histtools module
---------------------------------------------

.. automodule:: hyperspy.external.astroML.histtools
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: hyperspy.external.astroML
    :members:
    :undoc-members:
    :show-inheritance:
